@@ -590,14 +590,15 @@ bool HighsCutGeneration::cmirCutGenerationHeuristic(double minEfficacy,
     double oneoveroneminusf0 = 1.0 / (1.0 - f0);
     if (oneoveroneminusf0 > maxCMirScale) continue;
 
-    double sqrnorm = scale * scale * continuoussqrnorm;
-    double viol = scale * continuouscontribution * oneoveroneminusf0 - downrhs;
+    double contscale = scale * oneoveroneminusf0;
+    double sqrnorm = contscale * contscale * continuoussqrnorm;
+    double viol = contscale * continuouscontribution - downrhs;
 
     for (HighsInt j : integerinds) {
       double scalaj = vals[j] * scale;
       double downaj = fast_floor(scalaj + kHighsTiny);
       double fj = scalaj - downaj;
-      double aj = downaj + std::max(0.0, fj - f0);
+      double aj = downaj + std::max(0.0, (fj - f0) * oneoveroneminusf0);
       updateViolationAndNorm(j, aj, viol, sqrnorm);
     }
 
@@ -622,14 +623,15 @@ bool HighsCutGeneration::cmirCutGenerationHeuristic(double minEfficacy,
     double oneoveroneminusf0 = 1.0 / (1.0 - f0);
     if (oneoveroneminusf0 > maxCMirScale) continue;
 
-    double sqrnorm = scale * scale * continuoussqrnorm;
-    double viol = scale * continuouscontribution * oneoveroneminusf0 - downrhs;
+    double contscale = scale * oneoveroneminusf0;
+    double sqrnorm = contscale * contscale * continuoussqrnorm;
+    double viol = contscale * continuouscontribution - downrhs;
 
     for (HighsInt j : integerinds) {
       double scalaj = vals[j] * scale;
       double downaj = fast_floor(scalaj + kHighsTiny);
       double fj = scalaj - downaj;
-      double aj = downaj + std::max(0.0, fj - f0);
+      double aj = downaj + std::max(0.0, (fj - f0) * oneoveroneminusf0);
       updateViolationAndNorm(j, aj, viol, sqrnorm);
     }
 
@@ -666,14 +668,15 @@ bool HighsCutGeneration::cmirCutGenerationHeuristic(double minEfficacy,
       continue;
     }
 
-    double sqrnorm = scale * scale * continuoussqrnorm;
-    double viol = scale * continuouscontribution * oneoveroneminusf0 - downrhs;
+    double contscale = scale * oneoveroneminusf0;
+    double sqrnorm = contscale * contscale * continuoussqrnorm;
+    double viol = contscale * continuouscontribution - downrhs;
 
     for (HighsInt j : integerinds) {
       double scalaj = vals[j] * scale;
       double downaj = fast_floor(scalaj + kHighsTiny);
       double fj = scalaj - downaj;
-      double aj = downaj + std::max(0.0, fj - f0);
+      double aj = downaj + std::max(0.0, (fj - f0) * oneoveroneminusf0);
       updateViolationAndNorm(j, aj, viol, sqrnorm);
     }
 
@@ -709,15 +712,50 @@ bool HighsCutGeneration::cmirCutGenerationHeuristic(double minEfficacy,
       double downaj = floor(double(scalaj + kHighsTiny));
       HighsCDouble fj = scalaj - downaj;
       HighsCDouble aj = downaj;
-      if (fj > f0) aj += fj - f0;
+      if (fj > f0) aj += (fj - f0) * oneoveroneminusf0;
 
       vals[j] = double(aj * bestdelta);
     }
   }
 
+#ifndef NDEBUG
+  // Check if the computed cut has the correct efficacy
+  {
+    double checkviol = -downrhs * bestdelta;
+    double checknorm = 0.0;
+    for (HighsInt j = 0; j != rowlen; ++j) {
+      if (vals[j] == 0.0) continue;
+      updateViolationAndNorm(j, vals[j], checkviol, checknorm);
+    }
+    double checkefficacy = checkviol / sqrt(checknorm);
+    // the efficacy can become infinite if the cut 0 <= -1 is derived
+    assert(fabs(checkefficacy - bestefficacy) < 0.001 ||
+           fabs(checkefficacy) >= 1e30);
+  }
+#endif
+
   return true;
 }
 
+double HighsCutGeneration::scale(double val) {
+  int expshift = 0;
+  std::frexp(val, &expshift);
+  expshift = -expshift;
+
+  // Don't scale the coefficients by more than +1024 (violations can increase)
+  expshift = std::min(10, expshift);
+
+  // Scale rhs
+  rhs = ldexp(rhs, expshift);
+
+  // Scale row
+  for (HighsInt i = 0; i != rowlen; ++i)
+    vals[i] = std::ldexp(vals[i], expshift);
+
+  // Return scaling factor
+  return std::ldexp(1.0, expshift);
+}
+
 bool HighsCutGeneration::postprocessCut() {
   // right hand sides slightly below zero are likely due to numerical errors and
   // can cause numerical troubles with scaling, so set them to zero
@@ -782,6 +820,8 @@ bool HighsCutGeneration::postprocessCut() {
     }
   }
 
+  if (rowlen == 0) return false;
+
   if (integralSupport) {
     // integral support -> determine scale to make all coefficients integral
     double intscale =
@@ -847,25 +887,12 @@ bool HighsCutGeneration::postprocessCut() {
       for (HighsInt i = 0; i != rowlen; ++i)
         minAbsValue = std::min(std::abs(vals[i]), minAbsValue);
 
-      int expshift;
-      std::frexp(minAbsValue - epsilon, &expshift);
-      expshift = -expshift;
-
-      rhs = std::ldexp((double)rhs, expshift);
-
-      for (HighsInt i = 0; i != rowlen; ++i)
-        vals[i] = std::ldexp(vals[i], expshift);
+      scale(minAbsValue - epsilon);
     }
   } else {
     // the support is not integral, scale cut to have the largest coefficient
     // around 1.0
-    int expshift;
-    std::frexp(maxAbsValue - epsilon, &expshift);
-    expshift = -expshift;
-    rhs = std::ldexp((double)rhs, expshift);
-
-    for (HighsInt i = 0; i != rowlen; ++i)
-      vals[i] = std::ldexp(vals[i], expshift);
+    scale(maxAbsValue - epsilon);
   }
 
   return true;
@@ -893,12 +920,7 @@ bool HighsCutGeneration::preprocessBaseInequality(bool& hasUnboundedInts,
   for (HighsInt i = 0; i < rowlen; ++i)
     maxAbsVal = std::max(std::abs(vals[i]), maxAbsVal);
 
-  int expshift = 0;
-  std::frexp(maxAbsVal, &expshift);
-  expshift = -expshift;
-  initialScale = std::ldexp(1.0, expshift);
-  rhs *= initialScale;
-  for (HighsInt i = 0; i < rowlen; ++i) vals[i] = std::ldexp(vals[i], expshift);
+  initialScale = scale(maxAbsVal);
 
   isintegral.resize(rowlen);
   for (HighsInt i = 0; i != rowlen; ++i) {
