@@ -298,9 +298,8 @@ void HighsPrimalHeuristics::rootReducedCost() {
   HeuristicNeighbourhood neighbourhood(mipsolver, localdom);
 
   double currCutoff = kHighsInf;
-  double lower_bound;
-
-  lower_bound = mipsolver.mipdata_->lower_bound + mipsolver.mipdata_->feastol;
+  double lower_bound =
+      mipsolver.mipdata_->lower_bound + mipsolver.mipdata_->feastol;
 
   for (const std::pair<double, HighsDomainChange>& domchg : lurkingBounds) {
     currCutoff = domchg.first;
@@ -315,17 +314,9 @@ void HighsPrimalHeuristics::rootReducedCost() {
       if (localdom.infeasible()) {
         localdom.conflictAnalysis(mipsolver.mipdata_->conflictPool);
 
-        double prev_lower_bound = mipsolver.mipdata_->lower_bound;
+        mipsolver.mipdata_->updateLowerBound(
+            std::max(mipsolver.mipdata_->lower_bound, currCutoff));
 
-        mipsolver.mipdata_->lower_bound =
-            std::max(mipsolver.mipdata_->lower_bound, currCutoff);
-
-        const bool bound_change =
-            mipsolver.mipdata_->lower_bound != prev_lower_bound;
-        if (!mipsolver.submip && bound_change)
-          mipsolver.mipdata_->updatePrimalDualIntegral(
-              prev_lower_bound, mipsolver.mipdata_->lower_bound,
-              mipsolver.mipdata_->upper_bound, mipsolver.mipdata_->upper_bound);
         localdom.backtrack();
         if (localdom.getBranchDepth() == 0) break;
         neighbourhood.backtracked();
@@ -1485,8 +1476,8 @@ void HighsPrimalHeuristics::feasibilityPump() {
   std::vector<double> fracintcost;
   std::vector<HighsInt> fracintset;
 
-  std::vector<HighsInt> mask(mipsolver.model_->num_col_, 1);
-  std::vector<double> cost(mipsolver.model_->num_col_, 0.0);
+  std::vector<HighsInt> mask(mipsolver.numCol(), 1);
+  std::vector<double> cost(mipsolver.numCol(), 0.0);
 
   lprelax.getLpSolver().setOptionValue("simplex_strategy",
                                        kSimplexStrategyPrimal);
@@ -1505,7 +1496,7 @@ void HighsPrimalHeuristics::feasibilityPump() {
 
     auto localdom = mipsolver.mipdata_->domain;
     for (HighsInt i : mipsolver.mipdata_->integer_cols) {
-      assert(mipsolver.variableType(i) == HighsVarType::kInteger);
+      assert(mipsolver.isColInteger(i));
       double intval = std::floor(roundedsol[i] + randgen.real(0.4, 0.6));
       intval = std::max(intval, localdom.col_lower_[i]);
       intval = std::min(intval, localdom.col_upper_[i]);
@@ -1555,7 +1546,7 @@ void HighsPrimalHeuristics::feasibilityPump() {
       break;
 
     for (HighsInt i : mipsolver.mipdata_->integer_cols) {
-      assert(mipsolver.variableType(i) == HighsVarType::kInteger);
+      assert(mipsolver.isColInteger(i));
 
       if (mipsolver.mipdata_->uplocks[i] == 0 ||
           mipsolver.mipdata_->downlocks[i] == 0)
